The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {multiCorr}


Type: Package
Title: Multicovariance and Multicorrelation for p-Variables
Version: 0.1.0
Description: Implements the multicorrelation coefficient for p-variables as described in Cankaya (2023). The package provides a numerically stable implementation using logarithmic transformations and a log-sum-exp approach to reduce numerical overflow and underflow when calculations involve a large number of variables.
License: GPL-3
Encoding: UTF-8
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-09-07 08:16:08 UTC; mehmet.cankaya
Author: Mehmet Niyazi Cankaya [aut, cre]
Maintainer: Mehmet Niyazi Cankaya <mehmet.cankaya@usak.edu.tr>
Repository: CRAN
Date/Publication: 2026-09-15 11:50:08 UTC

Calculate Multicorrelation for p-Variables

Description

Computes the multicorrelation coefficient for p variables.

Usage

multicorrelation(x, r = 1)

Arguments

x

A numeric matrix or data frame.

r

A positive numeric power parameter. Default is 1.

Details

Each variable is centered by its arithmetic mean and scaled by its mean absolute deviation from the mean. Logarithmic transformations and a log-sum-exp approach are used to improve numerical stability.

Value

A numeric multicorrelation coefficient.

References

Cankaya, M. N. (2023). Multicovariance and Multicorrelation for p-variables. In Mathematical Methods for Engineering Applications (ICMASE 2022), pp. 273-284. Cham: Springer International Publishing.

Examples

set.seed(123)
X <- matrix(rnorm(1000), nrow = 100, ncol = 10)
multicorrelation(X)

multicorrelation(X, r = 2)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.